!-------------------------------------------------------------------------------

!                      Code_Saturne version 3.0.1
!                      --------------------------
! This file is part of Code_Saturne, a general-purpose CFD tool.
!
! Copyright (C) 1998-2013 EDF S.A.
!
! This program is free software; you can redistribute it and/or modify it under
! the terms of the GNU General Public License as published by the Free Software
! Foundation; either version 2 of the License, or (at your option) any later
! version.
!
! This program is distributed in the hope that it will be useful, but WITHOUT
! ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
! FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
! details.
!
! You should have received a copy of the GNU General Public License along with
! this program; if not, write to the Free Software Foundation, Inc., 51 Franklin
! Street, Fifth Floor, Boston, MA 02110-1301, USA.

!-------------------------------------------------------------------------------

!===============================================================================

!_______________________________________________________________________________

subroutine cs_user_boundary_conditions &
 ( nvar   , nscal  ,                                              &
   icodcl , itrifb , itypfb , izfppp ,                            &
   dt     , rtp    , rtpa   , propce , propfa , propfb ,          &
   rcodcl )

!===============================================================================

!===============================================================================
! Module files
!===============================================================================

use paramx
use numvar
use optcal
use cstphy
use cstnum
use entsor
use parall
use period
use ihmpre
use ppppar
use ppthch
use coincl
use cpincl
use ppincl
use ppcpfu
use atincl
use atsoil
use ctincl
use elincl
use cs_fuel_incl
use mesh

!===============================================================================

implicit none

! Arguments

integer          nvar   , nscal

integer          icodcl(nfabor,nvarcl)
integer          itrifb(nfabor), itypfb(nfabor)
integer          izfppp(nfabor)

double precision dt(ncelet), rtp(ncelet,*), rtpa(ncelet,*)
double precision propce(ncelet,*)
double precision propfa(nfac,*), propfb(nfabor,*)
double precision rcodcl(nfabor,nvarcl,3)

! Local variables

integer ifac, ilelt, nlelt, directin, directout
double precision Vtinner, Vtouter, omegai, omegao, Rinner, Router, ix, iy
logical Rotinner, Rotouter

! INSERT_VARIABLE_DEFINITIONS_HERE

integer, allocatable, dimension(:) :: lstelt

!===============================================================================


!===============================================================================
! Initialization
!===============================================================================

allocate(lstelt(nfabor))  ! temporary array for boundary faces selection

! INSERT_ADDITIONAL_INITIALIZATION_CODE_HERE

!===============================================================================
! Assign boundary conditions to boundary faces here

! For each subset:
! - use selection criteria to filter boundary faces of a given subset
! - loop on faces from a subset
!   - set the boundary condition for each face
!===============================================================================

! INSERT_MAIN_CODE_HERE

!Activate rotation for inner and/or outer wall (on: .true., off: .false.)

Rotinner = .true.
Rotouter = .false.

!Set Radius for inner cylinder (Rinner) and outer cylinder (Router)

Rinner= 0.05d0
Router= 0.055d0

!------------------------INNER CYLINDER--------------------------------

if (Rotinner .EQV. .true.) then

 call getfbr('inner_wall', nlelt, lstelt)

!Define direction of rotation (1:Clockwise, -1: Anticlockwise)
 
directin = 1

!Set rotational speed with rotational velocity omegai (rad/s)

omegai = 19.05d0

Vtinner = omegai*Rinner*directin

  do ilelt = 1, nlelt
ifac=lstelt(ilelt)

itypfb(ifac)=iparoi
 
ix=cdgfbo(1,ifac)
iy=cdgfbo(2,ifac)

   if (abs(ix)<0.000001)then
	if (iy>0)then
rcodcl(ifac,iu,1)=Vtinner
   else
rcodcl(ifac,iu,1)=-Vtinner
   end if

   else if (abs(iy)<0.000001)then
	if (ix>0)then
rcodcl(ifac,iv,1)=-Vtinner
   else
rcodcl(ifac,iv,1)=-Vtinner
   end if

   else

rcodcl(ifac,iu,1)=Vtinner*(iy/Rinner)
rcodcl(ifac,iv,1)=-Vtinner*(ix/Rinner)

   endif
  enddo

else if (Rotinner.EQV. .false.) then

 call getfbr('inner_wall', nlelt, lstelt)

  do ilelt = 1, nlelt

  ifac = lstelt(ilelt)

  itypfb(ifac) = iparoi
  enddo
endif

!------------------------OUTER CYLINDER--------------------------------

if (Rotouter .EQV. .true.) then

 call getfbr('outer_wall', nlelt, lstelt)

!Define direction of rotation (1:Clockwise, -1: Anticlockwise)
 
directout = -1

!Set rotational speed with rotational velocity omegao (rad/s)

omegao = 0.d0

Vtouter = omegao*Router*directout

  do ilelt = 1, nlelt
ifac=lstelt(ilelt)

itypfb(ifac)=iparoi
 
ix=cdgfbo(1,ifac)
iy=cdgfbo(2,ifac)

   if (abs(ix)<0.000001)then
	if (iy>0)then
rcodcl(ifac,iu,1)=Vtouter
   else
rcodcl(ifac,iu,1)=-Vtouter
   end if

   else if (abs(iy)<0.000001)then
	if (ix>0)then
rcodcl(ifac,iv,1)=-Vtouter
   else
rcodcl(ifac,iv,1)=-Vtouter
   end if

   else

rcodcl(ifac,iu,1)=Vtouter*(iy/Router)
rcodcl(ifac,iv,1)=-Vtouter*(ix/Router)

   endif
  enddo

else if (Rotouter.EQV. .false.) then

 call getfbr('outer_wall', nlelt, lstelt)

  do ilelt = 1, nlelt

  ifac = lstelt(ilelt)

  itypfb(ifac) = iparoi
  enddo
endif



!--------
! Formats
!--------

!----
! End
!----

deallocate(lstelt)  ! temporary array for boundary faces selection

return
end subroutine cs_user_boundary_conditions

!> \section examples Examples
!>   Several examples are provided
!>   \ref cs_user_boundary_conditions_examples "here".
