!-------------------------------------------------------------------------------

!                      Code_Saturne version 3.0.1
!                      --------------------------
! This file is part of Code_Saturne, a general-purpose CFD tool.
!
! Copyright (C) 1998-2013 EDF S.A.
!
! This program is free software; you can redistribute it and/or modify it under
! the terms of the GNU General Public License as published by the Free Software
! Foundation; either version 2 of the License, or (at your option) any later
! version.
!
! This program is distributed in the hope that it will be useful, but WITHOUT
! ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
! FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
! details.
!
! You should have received a copy of the GNU General Public License along with
! this program; if not, write to the Free Software Foundation, Inc., 51 Franklin
! Street, Fifth Floor, Boston, MA 02110-1301, USA.


!_______________________________________________________________________________

subroutine usvpst &
 ( ipart  ,                                                       &
   nvar   , nscal  , nvlsta ,                                     &
   ncelps , nfacps , nfbrps ,                                     &
   itypps ,                                                       &
   lstcel , lstfac , lstfbr ,                                     &
   dt     , rtpa   , rtp    , propce , propfa , propfb ,          &
   statis )

!===============================================================================

!===============================================================================

!===============================================================================
! Module files
!===============================================================================

use paramx
use cstnum
use pointe
use entsor
use optcal
use numvar
use parall
use period
use mesh
use field
use post
use f_velocity

!===============================================================================

implicit none

! Arguments

integer          ipart
integer          nvar,   nscal , nvlsta
integer          ncelps, nfacps, nfbrps

integer          itypps(3)
integer          lstcel(ncelps), lstfac(nfacps), lstfbr(nfbrps)

double precision dt(ncelet), rtpa(ncelet,*), rtp(ncelet,*), uet
double precision propce(ncelet,*)
double precision propfa(nfac,*), propfb(nfabor,*)
double precision statis(ncelet,nvlsta)

! Local variables

character*32     namevr

integer          ntindp
integer          iel, ifac, iloc, ivar
integer          idimt, ii , jj
logical          ientla, ivarpr
integer          imom1, imom2, ipcmo1, ipcmo2, idtcm
double precision pnd
double precision rvoid(1)

double precision, dimension(:), allocatable :: scel, sfac, sfbr, sh_stress, fricvel, sh_rate
double precision, dimension(:,:), allocatable :: vcel, vfac, vfbr
double precision, dimension(:), pointer :: coefap, coefbp

integer          intpst
data             intpst /0/
save             intpst

!===============================================================================


!===============================================================================
! Increment call counter once per time step (possibly used in some tests)
!===============================================================================

if (ipart .eq. -1) then
  intpst = intpst + 1
endif


if (ipart .eq. -2) then

allocate(sh_stress(nfbrps), fricvel(nfbrps), sh_rate(nfbrps))  

     do iloc = 1, nfbrps

      ifac = lstfbr(iloc)
      
      fricvel(iloc) = fvelo(ifac)
      sh_stress(iloc) = (fvelo(ifac)**2)*1140
      sh_rate(iloc) = sh_stress(ifac)/0.008
     enddo


      
  ! Output of the density at the boundary
  ! -------------------------------------

  idimt = 3        ! 1: scalar, 3: vector, 6/9: symm/non-symm tensor
  ientla = .true.  ! dimension 1 here, so no effect
  ivarpr = .true.  ! we use the propfb array defined on the parent mesh

  ! Output values; as we have no cell or interior face values, we can pass a
  ! trivial array for those.
  call post_write_var(ipart, 'Friction Velocity', 1, ientla, ivarpr,    &
                      ntcabs, ttcabs, rvoid, rvoid, fricvel)
  !call post_write_var(ipart, 'Forces', idimt, ientla, ivarpr,    &
       !               ntcabs, ttcabs, rvoid, rvoid, forbr)
  call post_write_var(ipart, 'Shear stress', 1, ientla, ivarpr,    &
                      ntcabs, ttcabs, rvoid, rvoid, sh_stress)
call post_write_var(ipart, 'Shear rate', 1, ientla, ivarpr,    &
                      ntcabs, ttcabs, rvoid, rvoid, sh_rate)
 ! call post_write_var(ipart, 'Area vector', idimt, ientla, ivarpr,    &
  !                    ntcabs, ttcabs, rvoid, rvoid, surfbo)
 ! call post_write_var(ipart, 'Area magnitude', 1, ientla, ivarpr,    &
 !                     ntcabs, ttcabs, rvoid, rvoid, surfbn)

deallocate(sh_stress, fricvel)
 
  endif

return

end subroutine usvpst
